==> cssutransitionstuner_0.1.2.tar.gz: cssutransitionstuner-0.1.2/src/opt/cssutransitionstuner/lang/German.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en_US">
<context>
    <name>mainwindow</name>
    <message>
        <source>CSSU Transitions tuner</source>
        <translation>CSSU Transitions Tuner</translation>
    </message>
    <message>
        <source>Ultra fast Transitions</source>
        <translation>Sehr schnelle Übergänge</translation>
    </message>
    <message>
        <source>Fast Transitions</source>
        <translation>Schnelle Übergänge</translation>
    </message>
    <message>
        <source>Normal Transitions</source>
        <translation>Normale Übergänge</translation>
    </message>
    <message>
        <source>Slow Transitions</source>
        <translation>Langsame Übergänge</translation>
    </message>
    <message>
        <source>Turtle Transitions</source>
        <translation>Sehr langsame Übergänge</translation>
    </message>
    <message>
        <source>Default style Task Switcher</source>
        <translation>Standard Task Switcher</translation>
    </message>
    <message>
        <source>Single column Task Switcher</source>
        <translation>Einreihiger Task Switcher</translation>
    </message>
    <message>
        <source>Double columns Task Switcher</source>
        <translation>Zweireihiger Task Switcher</translation>
    </message>
    <message>
        <source>App menu blur</source>
        <translation>Menü Unschärfe</translation>
    </message>
    <message>
        <source>Parallax</source>
        <translation>Parallax</translation>
    </message>
    <message>
        <source>Blurless saturation Enabled</source>
        <translation>Sättigung ohne Unschärfe aktiviert</translation>
    </message>
    <message>
        <source>Force rotation Enabled</source>
        <translation>Rotation erzwingen aktiviert</translation>
    </message>
    <message>
        <source>Rotate around z-axis Enabled</source>
        <translation>Rotation um Z-Achse aktiviert</translation>
    </message>
    <message>
        <source>Tactile feedback Enabled</source>
        <translation>Fühlbares Feedback aktiviert</translation>
    </message>
    <message>
        <source>Zoom on press Enabled</source>
        <translation>Zoom beim berühren aktiviert</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Author: d-iivil&lt;br /&gt;Licence: GPL</source>
        <translation>Autorr: d-iivil&lt;br /&gt;Licence: GPL&lt;br /&gt;Übersetzung: NightShift79</translation>
    </message>
    <message>
        <source>version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Transitions updated!</source>
        <translation>Übergänge aktualisiert!</translation>
    </message>
    <message>
        <source>Reboot is required to activate all changes.</source>
        <translation>Neustart wird benötigt um alle Änderungen zu aktivieren.</translation>
    </message>
</context>
</TS>

==> cssutransitionstuner_0.1.3.tar.gz: cssutransitionstuner-0.1.3/src/opt/cssutransitionstuner/lang/German.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en_US">
<context>
    <name>mainwindow</name>
    <message>
        <source>CSSU Transitions tuner</source>
        <translation>CSSU Transitions Tuner</translation>
    </message>
    <message>
        <source>Ultra fast Transitions</source>
        <translation>Sehr schnelle Übergänge</translation>
    </message>
    <message>
        <source>Fast Transitions</source>
        <translation>Schnelle Übergänge</translation>
    </message>
    <message>
        <source>Normal Transitions</source>
        <translation>Normale Übergänge</translation>
    </message>
    <message>
        <source>Slow Transitions</source>
        <translation>Langsame Übergänge</translation>
    </message>
    <message>
        <source>Turtle Transitions</source>
        <translation>Sehr langsame Übergänge</translation>
    </message>
    <message>
        <source>Default style Task Switcher</source>
        <translation>Standard Task Switcher</translation>
    </message>
    <message>
        <source>Single column Task Switcher</source>
        <translation>Einreihiger Task Switcher</translation>
    </message>
    <message>
        <source>Double columns Task Switcher</source>
        <translation>Zweireihiger Task Switcher</translation>
    </message>
    <message>
        <source>App menu blur</source>
        <translation>Menü Unschärfe</translation>
    </message>
    <message>
        <source>Parallax</source>
        <translation>Parallax</translation>
    </message>
    <message>
        <source>Blurless saturation Enabled</source>
        <translation>Sättigung ohne Unschärfe</translation>
    </message>
    <message>
        <source>Force rotation Enabled</source>
        <translation>Rotation erzwingen</translation>
    </message>
    <message>
        <source>Rotate around z-axis Enabled</source>
        <translation>Rotation um Z-Achse</translation>
    </message>
    <message>
        <source>Tactile feedback Enabled</source>
        <translation>Fühlbares Feedback</translation>
    </message>
    <message>
        <source>Zoom on press Enabled</source>
        <translation type="unfinished">Zoom beim Berühren</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Author: d-iivil&lt;br /&gt;Licence: GPL</source>
        <translation>Autor: d-iivil&lt;br /&gt;Licence: GPL&lt;br /&gt;Übersetzung: NightShift79</translation>
    </message>
    <message>
        <source>version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Transitions updated!</source>
        <translation>Übergänge aktualisiert!</translation>
    </message>
    <message>
        <source>Reboot is required to activate all changes.</source>
        <translation>Neustart wird benötigt um alle Änderungen zu aktivieren.</translation>
    </message>
</context>
</TS>
